@@ -16,7 +16,7 @@
 
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
 
@@ -30,8 +30,7 @@
 @interface CairoFontInfo : GSFontInfo
 {
 @public
-	cairo_t *_cf;
-	cairo_font_t *xrFont;
+	cairo_scaled_font_t *_scaled;
 
 	CairoFaceInfo *_faceInfo;
 
@@ -49,9 +48,7 @@
 - (void) setCacheSize:(unsigned int)size;
 - (void) drawGlyphs: (const NSGlyph*)glyphs
 	     length: (int)length 
-	         on: (cairo_t*)ct
-		atX: (double)dx
-                  y: (double)dy;
+	         on: (cairo_t*)ct;
 @end
 
 #endif
