@@ -19,7 +19,7 @@
    
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
    */
 
 #ifndef _WIN32GState_h_INCLUDE
@@ -48,6 +48,12 @@
 
 - (void) setWindow: (HWND)number;
 - (HWND) window;
+// declared to fix conflicting type with super class warning during compile 
+- (void) compositeGState: (WIN32GState *) source
+		fromRect: (NSRect) sourceRect
+		 toPoint: (NSPoint) destPoint
+		      op: (NSCompositingOperation) op
+		fraction: (float)delta;
 
 @end
 
