@@ -20,6 +20,7 @@
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
+#include "GNUstepBase/Unicode.h"
 #include <AppKit/NSAffineTransform.h>
 #include "cairo/CairoFontInfo.h"
 #include "cairo/CairoFontEnumerator.h"
@@ -41,7 +42,9 @@
       free(_cachedGlyphs);
     }
   _cachedSizes = malloc(sizeof(NSSize) * size);
+  memset(_cachedSizes, 0, sizeof(NSSize) * size);
   _cachedGlyphs = malloc(sizeof(unsigned int) * size);
+  memset(_cachedGlyphs, 0, sizeof(unsigned int) * size);
 }
 
 - (BOOL) setupAttributes
@@ -89,6 +92,7 @@
       return NO;
     }
   _scaled = cairo_scaled_font_create(face, &font_matrix, &ctm, options);
+  cairo_font_options_destroy(options);
   if (!_scaled)
     {
       return NO;
@@ -154,46 +158,30 @@
   return YES;
 }
 
-// FIXME: This function is not exported by Cairo. The parameters have changed in recent cairo!!!
-extern
-cairo_status_t
-_cairo_scaled_font_text_to_glyphs (cairo_scaled_font_t *scaled_font,
-				   const char          *utf8, 
-				   cairo_glyph_t      **glyphs, 
-				   int 		       *num_glyphs);
-
-static
-BOOL _cairo_extents_for_text(cairo_scaled_font_t *scaled_font, const char *utf8,
-			     cairo_text_extents_t *ctext)
-{
-  cairo_glyph_t *glyphs = NULL;
-  int num_glyphs;
-  cairo_status_t status;
-
-  status = _cairo_scaled_font_text_to_glyphs(scaled_font, utf8, 
-					     &glyphs, &num_glyphs);
-  if (glyphs)
-    {
-      cairo_scaled_font_glyph_extents(scaled_font, glyphs, num_glyphs, ctext);
-      free(glyphs);
-
-      return YES;
-    }
-
-  return NO;
-}
-
 static
 BOOL _cairo_extents_for_NSGlyph(cairo_scaled_font_t *scaled_font, NSGlyph glyph,
 				cairo_text_extents_t *ctext)
 {
-  char str[3];
+  unichar ustr[2];
+  char str[4];
+  unsigned char *b;
+  unsigned int size = 4;
+  int length = 1;
 
-  // FIXME: This is wrong for none ASCII characters!
-  str[0] = glyph;
-  str[1] = 0;
-  
-  return _cairo_extents_for_text(scaled_font, str, ctext);
+  ustr[0] = glyph;
+  ustr[1] = 0;
+
+  b = (unsigned char *)str;
+  if (!GSFromUnicode(&b, &size, ustr, length, 
+		     NSUTF8StringEncoding, NULL, GSUniTerminate))
+    {
+      NSLog(@"Conversion failed for %@", 
+	    [NSString stringWithCharacters: ustr length: length]);
+      return NO;
+    }
+
+  cairo_scaled_font_text_extents(scaled_font, str, ctext);
+  return cairo_scaled_font_status(scaled_font) == CAIRO_STATUS_SUCCESS;
 }
 
 - (NSSize) advancementForGlyph: (NSGlyph)glyph
@@ -236,7 +224,8 @@ BOOL _cairo_extents_for_NSGlyph(cairo_scaled_font_t *scaled_font, NSGlyph glyph,
 {
   cairo_text_extents_t ctext;
 
-  if (_cairo_extents_for_text(_scaled, [string UTF8String], &ctext))
+	cairo_scaled_font_text_extents(_scaled, [string UTF8String], &ctext);
+  if (cairo_scaled_font_status(_scaled) == CAIRO_STATUS_SUCCESS)
     {
       return ctext.width;
     }
@@ -277,23 +266,52 @@ BOOL _cairo_extents_for_NSGlyph(cairo_scaled_font_t *scaled_font, NSGlyph glyph,
 	         on: (cairo_t*)ct
 {
   cairo_matrix_t font_matrix;
-  char str[length+1];
+  unichar ustr[length+1];
+  char str[3*length+1];
+  unsigned char *b;
   int i;
+  unsigned int size = 3*length+1;
 
   for (i = 0; i < length; i++)
     {
-      str[i] = glyphs[i];
+      ustr[i] = glyphs[i];
+    }
+  ustr[length] = 0;
+
+  b = (unsigned char *)str;
+  if (!GSFromUnicode(&b, &size, ustr, length, 
+		     NSUTF8StringEncoding, NULL, GSUniTerminate))
+    {
+      NSLog(@"Conversion failed for %@", 
+	    [NSString stringWithCharacters: ustr length: length]);
+      return;
     }
-  str[length] = 0;
 
   cairo_matrix_init(&font_matrix, matrix[0], matrix[1], matrix[2],
 		    -matrix[3], matrix[4], matrix[5]);
-  cairo_set_font_face(ct, [_faceInfo fontFace]);
   cairo_set_font_matrix(ct, &font_matrix);
+  if (cairo_status(ct) != CAIRO_STATUS_SUCCESS)
+    {
+	NSLog(@"Error while setting font matrix: %s", 
+	      cairo_status_to_string(cairo_status(ct)));
+	return;
+    }
+  cairo_set_font_face(ct, [_faceInfo fontFace]);
+  if (cairo_status(ct) != CAIRO_STATUS_SUCCESS)
+    {
+	NSLog(@"Error while setting font face: %s", 
+	      cairo_status_to_string(cairo_status(ct)));
+	return;
+    }
 
   // FIXME: Need some adjustment here
   cairo_rel_move_to(ct, 0.0, -5.0);
   cairo_show_text(ct, str);
+  if (cairo_status(ct) != CAIRO_STATUS_SUCCESS)
+    {
+	NSLog(@"Error drawing string: '%s' for string %s", 
+	      cairo_status_to_string(cairo_status(ct)), str);
+    }
 }
  
 @end
