@@ -4,6 +4,9 @@
  * Copyright (C) 2003 Free Software Foundation, Inc.
  * August 31, 2003
  * Written by Banlu Kemiyatorn <object at gmail dot com>
+ * Rewrite: Fred Kiefer <fredkiefer@gmx.de>
+ * Date: Jan 2006
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -26,13 +29,10 @@
 #include "cairo/CairoFontInfo.h"
 #include "cairo/CairoSurface.h"
 #include "cairo/CairoContext.h"
-#include "NSBezierPathCairo.h"
 #include <math.h>
 
 #define FIXME()  NSLog(@":::FIXME::: %@ %s", [self description], sel_get_name(_cmd))
 
-static cairo_matrix_t local_matrix;
-
 /* Be warned that CairoGState didn't derived GSGState */
 @implementation CairoGState 
 
@@ -58,6 +58,7 @@ static cairo_matrix_t local_matrix;
     {
       cairo_path_t *path;
       cairo_status_t status;
+      cairo_matrix_t local_matrix;
  
       // FIXME: Need some way to do a copy
       //cairo_copy(copy->_ct, _ct);
@@ -67,6 +68,15 @@ static cairo_matrix_t local_matrix;
       path = cairo_copy_path(_ct);
       cairo_append_path(copy->_ct, path);
       cairo_path_destroy(path);
+      
+      cairo_set_operator(copy->_ct, cairo_get_operator(_ct));
+      cairo_set_source(copy->_ct, cairo_get_source(_ct));
+      cairo_set_tolerance(copy->_ct, cairo_get_tolerance(_ct));
+      cairo_set_antialias(copy->_ct, cairo_get_antialias(_ct));
+      cairo_set_line_width(copy->_ct, cairo_get_line_width(_ct));
+      cairo_set_line_cap(copy->_ct, cairo_get_line_cap(_ct));
+      cairo_set_line_join(copy->_ct, cairo_get_line_join(_ct));
+      cairo_set_miter_limit(copy->_ct, cairo_get_miter_limit(_ct));
       //NSLog(@"copy gstate old %d new %d", _ct, copy->_ct);
  
       status = cairo_status(copy->_ct);
@@ -76,14 +86,6 @@ static cairo_matrix_t local_matrix;
 	}
     }
 
-  /*
-     NSLog(@"copy state %p(%p) to %p(%p)",self,
-     cairo_get_target(_ct),
-     copy,
-     cairo_get_target(copy->_ct)
-);
-   */
-
   RETAIN(_font);
   RETAIN(_surface);
 
@@ -106,7 +108,6 @@ static cairo_matrix_t local_matrix;
 
 - (void) dealloc
 {
-  //NSLog(@"destate %p",self);
   if (_ct)
     {
       cairo_destroy(_ct);
@@ -120,6 +121,8 @@ static cairo_matrix_t local_matrix;
 static void
 _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
 {
+  cairo_matrix_t local_matrix;
+
   cairo_matrix_init_scale(&local_matrix, 1, -1);
 
   if (surface != nil)
@@ -167,16 +170,15 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
   _offset = NSMakePoint(x, y);
 
   [self DPSinitgraphics];
-/*
-  NSLog(@"after: surface %p on state %p %@",
-	cairo_get_target (_ct), self,
-	NSStringFromSize([_surface size]));
-*/
 }
 
 @end 
 
 @implementation CairoGState (Ops)
+
+// FIXME: Hack to be able to set alpha
+static float last_r, last_g, last_b;
+
 /*
  * Color operations
  */
@@ -225,22 +227,22 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
 
 - (void) DPScurrentrgbcolor: (float *)r : (float *)g : (float *)b
 {
-  double dr, dg, db;
-
-  //FIXME: 
+  //FIXME: cairo removed this function
   //cairo_current_rgb_color(_ct, &dr, &dg, &db);
-  dr = dg = db = 0.8;
-  *r = dr;
-  *g = dg;
-  *b = db;
+  *r = last_r;
+  *g = last_g;
+  *b = last_b;
 }
 
 - (void) DPSsetalpha: (float)a
 {
-//  float r, g, b;
+  float r, g, b;
 
-  //FIXME
-  //cairo_set_source_rgba(_ct, r, g, b, a);
+  // FIXME: Hack to be able to set alpha
+  r = last_r;
+  g = last_g;
+  b = last_b;
+  cairo_set_source_rgba(_ct, r, g, b, a);
 }
 
 - (void) DPSsetcmykcolor: (float)c : (float)m : (float)y : (float)k
@@ -250,12 +252,12 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
   r = 1 - c;
   g = 1 - m;
   b = 1 - y;
-  cairo_set_source_rgb(_ct, r, g, b);
+  [self DPSsetrgbcolor: r : g : b];
 }
 
 - (void) DPSsetgray: (float)gray
 {
-  cairo_set_source_rgb(_ct, gray, gray, gray);
+  [self DPSsetrgbcolor: gray : gray : gray];
 }
 
 - (void) DPSsethsbcolor: (float)h : (float)s : (float)b
@@ -276,6 +278,10 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
 
 - (void) DPSsetrgbcolor: (float)r : (float)g: (float)b
 {
+  // FIXME: Hack to be able to set alpha
+  last_r = r;
+  last_g = g;
+  last_b = b;
   cairo_set_source_rgb(_ct, r, g, b);
 }
 
@@ -436,10 +442,14 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
     {
       NSLog(@"Cairo status %s in DPSinitgraphics", cairo_status_to_string(status));
     }
-  _flipCairoSurfaceMatrix(_ct, _surface);
+  if (!_viewIsFlipped)
+    {
+      _flipCairoSurfaceMatrix(_ct, _surface);
+    }
   //NSLog(@"in flip %p (%p)", self, cairo_get_target(_ct));
   /* Cairo's default line width is 2.0 */
   cairo_set_line_width(_ct, 1.0);
+  cairo_set_operator(_ct, CAIRO_OPERATOR_OVER);
 }
 
 - (void) DPScurrentflat: (float *)flatness
@@ -573,6 +583,8 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
 
 - (void) DPSconcat: (const float *)m
 {
+  cairo_matrix_t local_matrix;
+
   cairo_matrix_init(&local_matrix, m[0], m[1], m[2], m[3], m[4], m[5]);
   cairo_transform(_ct, &local_matrix);
 }
@@ -580,7 +592,10 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
 - (void) DPSinitmatrix
 {
   cairo_identity_matrix(_ct);
-  _flipCairoSurfaceMatrix(_ct, _surface);
+  if (!_viewIsFlipped)
+    {
+      _flipCairoSurfaceMatrix(_ct, _surface);
+    }
 }
 
 - (void) DPSrotate: (float)angle
@@ -600,26 +615,18 @@ _flipCairoSurfaceMatrix(cairo_t *ct, CairoSurface *surface)
 
 - (void) _flipCairoFont
 {
+  cairo_matrix_t local_matrix;
+
   cairo_matrix_init_scale(&local_matrix, 1, -1);
   cairo_set_font_matrix(_ct, &local_matrix);
 }
 
-/*
-static void
-_log_matrix(cairo_t * ct)
-{
-  cairo_get_matrix(ct, &local_matrix);
-
-  NSLog(@"%g %g %g %g %g %g", local_matrix.xx, local_matrix.yx, local_matrix.xy, 
-                              local_matrix.yy, local_matrix.x0, local_matrix.y0);
-}
-*/
-
 - (NSAffineTransform *) GSCurrentCTM
 {
   NSAffineTransform *transform;
   NSAffineTransformStruct tstruct;
   cairo_matrix_t flip_matrix;
+  cairo_matrix_t local_matrix;
 
   transform = [NSAffineTransform transform];
   cairo_get_matrix(_ct, &local_matrix);
@@ -627,6 +634,8 @@ _log_matrix(cairo_t * ct)
   NSLog(@"Before flip %f %f, %f, %f, %f, %f", local_matrix.xx, local_matrix.yx, 
 	local_matrix.xy, local_matrix.yy, local_matrix.x0, local_matrix.y0);
 */
+  if (!_viewIsFlipped)
+    {
   if (_surface)
   {
      cairo_matrix_init_translate(&flip_matrix, 0, -[_surface size].height);
@@ -634,6 +643,7 @@ _log_matrix(cairo_t * ct)
    }
   cairo_matrix_init_scale(&flip_matrix, 1, -1);
   cairo_matrix_multiply(&local_matrix, &local_matrix, &flip_matrix);
+    }
 /*
   NSLog(@"After flip %f %f, %f, %f, %f, %f", local_matrix.xx, local_matrix.yx, 
 	local_matrix.xy, local_matrix.yy, local_matrix.x0, local_matrix.y0);
@@ -651,8 +661,12 @@ _log_matrix(cairo_t * ct)
 - (void) GSSetCTM: (NSAffineTransform *)ctm
 {
   NSAffineTransformStruct tstruct;
+  cairo_matrix_t local_matrix;
 
-  _flipCairoSurfaceMatrix(_ct, _surface);
+  if (!_viewIsFlipped)
+    {
+      _flipCairoSurfaceMatrix(_ct, _surface);
+    }
   tstruct = [ctm transformStruct];
   cairo_matrix_init(&local_matrix,
 		    tstruct.m11, tstruct.m12,
@@ -664,6 +678,7 @@ _log_matrix(cairo_t * ct)
 - (void) GSConcatCTM: (NSAffineTransform *)ctm
 {
   NSAffineTransformStruct tstruct;
+  cairo_matrix_t local_matrix;
 
   tstruct =  [ctm transformStruct];
   cairo_matrix_init(&local_matrix,
@@ -784,9 +799,45 @@ _log_matrix(cairo_t * ct)
   cairo_new_path(_ct);
 }
 
+- (NSBezierPath *) bezierPath
+{
+  int i;
+  cairo_path_t *cpath;
+  cairo_path_data_t *data;
+  NSBezierPath *path =[NSBezierPath bezierPath];
+
+  cpath = cairo_copy_path(_ct);
+
+  for (i=0; i < cpath->num_data; i += cpath->data[i].header.length) 
+    {
+      data = &cpath->data[i];
+      switch (data->header.type) 
+        {
+	  case CAIRO_PATH_MOVE_TO:
+	    [path moveToPoint: NSMakePoint(data[1].point.x, data[1].point.y)];
+	    break;
+	  case CAIRO_PATH_LINE_TO:
+	    [path lineToPoint: NSMakePoint(data[1].point.x, data[1].point.y)];
+	    break;
+	  case CAIRO_PATH_CURVE_TO:
+	    [path curveToPoint: NSMakePoint(data[1].point.x, data[1].point.y) 
+		 controlPoint1: NSMakePoint(data[2].point.x, data[2].point.y) 
+		 controlPoint2: NSMakePoint(data[3].point.x, data[3].point.y)];
+	    break;
+	  case CAIRO_PATH_CLOSE_PATH:
+	    [path closePath];
+	    break;
+	}
+    }
+
+  cairo_path_destroy(cpath);
+
+  return path;
+}
+
 - (void) DPSpathbbox: (float *)llx : (float *)lly : (float *)urx : (float *)ury
 {
-  NSBezierPath *path = [NSBezierPath bezierPathFromCairo: _ct];
+  NSBezierPath *path = [self bezierPath];
   NSRect rect = [path controlPointBounds];
 
   if (llx)
@@ -845,11 +896,10 @@ _log_matrix(cairo_t * ct)
 
 - (void) DPSreversepath
 {
-  NSBezierPath *path = [NSBezierPath bezierPathFromCairo: _ct];
+  NSBezierPath *path = [self bezierPath];
 
   path = [path bezierPathByReversingPath];
-  cairo_new_path(_ct);
-  [path appendBezierPathToCairo: _ct];
+  [self GSSendBezierPath: path];
 }
 
 - (void) DPSrlineto: (float)x : (float)y
@@ -869,8 +919,46 @@ _log_matrix(cairo_t * ct)
 
 - (void) GSSendBezierPath: (NSBezierPath *)path
 {
+  int i, n;
+  int count = 10;
+  float dash_pattern[10];
+  float phase;
+  NSPoint pts[3];
+  NSBezierPathElement e;
+  SEL elmsel = @selector(elementAtIndex: associatedPoints:);
+  IMP elmidx = [path methodForSelector: elmsel];
+
   cairo_new_path(_ct);
-  [path appendBezierPathToCairo: _ct];
+
+  n = [path elementCount];
+  for (i = 0; i < n; i++)
+    {
+      e = (NSBezierPathElement)(*elmidx)(path, elmsel, i, pts);
+      switch (e)
+	{
+	case NSMoveToBezierPathElement:
+	  cairo_move_to(_ct, pts[0].x, pts[0].y);
+	  break;
+	case NSLineToBezierPathElement:
+	  cairo_line_to(_ct, pts[0].x, pts[0].y);
+	  break;
+	case NSCurveToBezierPathElement:
+	  cairo_curve_to(_ct, pts[0].x, pts[0].y, pts[1].x, pts[1].y,
+			 pts[2].x, pts[2].y);
+	  break;
+	case NSClosePathBezierPathElement:
+	  cairo_close_path(_ct);
+	  break;
+	}
+    }
+
+  cairo_set_line_width(_ct, [path lineWidth]);
+  cairo_set_line_join(_ct, (cairo_line_join_t)[path lineJoinStyle]);
+  cairo_set_line_cap(_ct, (cairo_line_cap_t)[path lineCapStyle]);
+  cairo_set_miter_limit(_ct, [path miterLimit]);
+
+  [path getLineDash: dash_pattern count: &count phase: &phase];
+  [self DPSsetdash: dash_pattern : count : phase];
 }
 
 - (void) GSRectClipList: (const NSRect *)rects : (int)count
@@ -905,61 +993,6 @@ _log_matrix(cairo_t * ct)
     }
 }
 
-/*
-static NSString *
-_opName(NSCompositingOperation op)
-{
-  switch (op)
-    {
-    case NSCompositeClear:
-      return @"NSCompositeClear";
-
-    case NSCompositeCopy:
-      return @"NSCompositeCopy";
-
-    case NSCompositeSourceOver:
-      return @"NSCompositeSourceOver";
-
-    case NSCompositeSourceIn:
-      return @"NSCompositeSourceIn";
-
-    case NSCompositeSourceOut:
-      return @"NSCompositeSourceOut";
-
-    case NSCompositeSourceAtop:
-      return @"NSCompositeSourceAtop";
-
-    case NSCompositeDestinationOver:
-      return @"NSCompositeDestinationOver";
-
-    case NSCompositeDestinationIn:
-      return @"NSCompositeDestinationIn";
-
-    case NSCompositeDestinationOut:
-      return @"NSCompositeDestinationOut";
-
-    case NSCompositeDestinationAtop:
-      return @"NSCompositeDestinationAtop";
-
-    case NSCompositeXOR:
-      return @"NSCompositeXOR";
-
-    case NSCompositePlusDarker:
-      return @"NSCompositePlusDarker";
-
-    case NSCompositeHighlight:
-      return @"NSCompositeHighlight";
-
-    case NSCompositePlusLighter:
-      return @"NSCompositePlusLighter";
-
-    default:
-      return @"default";
-
-    }
-}
-*/
-
 static void
 _set_op(cairo_t * ct, NSCompositingOperation op)
 {
@@ -1025,8 +1058,11 @@ _set_op(cairo_t * ct, NSCompositingOperation op)
   unsigned char	*tmp;
   int i = 0;
   int j;
+  int index;
   unsigned int pixels = pixelsHigh * pixelsWide;
   const unsigned char *bits = data[0];
+  unsigned char *rowData;
+  cairo_matrix_t local_matrix;
 
 /*
   NSLog(@"%@ DPSimage %dx%d (%p)", self, pixelsWide, pixelsHigh,
@@ -1039,33 +1075,64 @@ _set_op(cairo_t * ct, NSCompositingOperation op)
       return;
     }
 
-  switch (bitsPerSample * samplesPerPixel)
+  // default is 8 bit grayscale 
+  if (!bitsPerSample)
+    bitsPerSample = 8;
+  if (!samplesPerPixel)
+    samplesPerPixel = 1;
+
+  // FIXME - does this work if we are passed a planar image but no hints ?
+  if (!bitsPerPixel)
+    bitsPerPixel = bitsPerSample * samplesPerPixel;
+  if (!bytesPerRow)
+    bytesPerRow = (bitsPerPixel * pixelsWide) / 8;
+
+  /* make sure its sane - also handles row padding if hint missing */
+  while ((bytesPerRow * 8) < (bitsPerPixel * pixelsWide))
+    bytesPerRow++;
+
+  switch (bitsPerPixel)
     {
     case 32:
+      rowData = (unsigned char *)bits;
       tmp = objc_malloc(pixels * 4);
-      while (i < pixels * 4)
-	{
-	  tmp[i+0] = bits[i+2];
-	  tmp[i+1] = bits[i+1];
-	  tmp[i+2] = bits[i+0];
-	  tmp[i+3] = bits[i+3];
-	  i += 4;
+      index = 0;
+
+      for (i = 0; i < pixelsHigh; i++)
+        {
+	  unsigned char *d = rowData;
+
+	  for (j = 0; j < pixelsWide; j++)
+	    {
+	      tmp[index++] = d[2];
+	      tmp[index++] = d[1];
+	      tmp[index++] = d[0];
+	      tmp[index++] = d[3];
+	      d += 4;
+	    }
+	  rowData += bytesPerRow;
 	}
       bits = tmp;
       format = CAIRO_FORMAT_ARGB32;
       break;
     case 24:
+      rowData = (unsigned char *)bits;
       tmp = objc_malloc(pixels * 4);
-      i = 0;
-      j = 0;
-      while (i < pixels * 4)
-	{
-	  tmp[i+0] = bits[j+2];
-	  tmp[i+1] = bits[j+1];
-	  tmp[i+2] = bits[j+0];
-	  tmp[i+3] = 0;
-	  i += 4;
-	  j += 3;
+      index = 0;
+
+      for (i = 0; i < pixelsHigh; i++)
+        {
+	  unsigned char *d = rowData;
+
+	  for (j = 0; j < pixelsWide; j++)
+	    {
+	      tmp[index++] = d[2];
+	      tmp[index++] = d[1];
+	      tmp[index++] = d[0];
+	      tmp[index++] = 0;
+	      d += 3;
+	    }
+	  rowData += bytesPerRow;
 	}
       bits = tmp;
       format = CAIRO_FORMAT_RGB24;
@@ -1074,60 +1141,79 @@ _set_op(cairo_t * ct, NSCompositingOperation op)
       NSLog(@"Image format not support");
       return;
     }
-//      [self DPSinitclip];
-
-  tstruct = [matrix transformStruct];
-  /*
-     NSLog(@"%g %g %g %g %g %g",
-     tstruct.m11, tstruct.m12,
-     tstruct.m21, tstruct.m22,
-     tstruct.tX, tstruct.tY);
-  */
-  cairo_save(_ct);
-  _flipCairoSurfaceMatrix(_ct, _surface);
-  cairo_matrix_init(&local_matrix,
-		    tstruct.m11, tstruct.m12,
-		    tstruct.m21, tstruct.m22, 
-		    tstruct.tX, tstruct.tY);
-  cairo_transform(_ct, &local_matrix);
 
   surface = cairo_image_surface_create_for_data((void*)bits,
 						format,
 						pixelsWide,
 						pixelsHigh,
-						bytesPerRow);
-
-  if (bits != data[0])
-    {
-      objc_free(bits);
-    }
+						pixelsWide * 4);
 
   if (surface == NULL)
     {
       NSLog(@"Image surface could not be created");
+      if (bits != data[0])
+        {
+	  objc_free((unsigned char *)bits);
+	}
+
       return;
     }
 
-  cairo_set_source_surface(_ct, surface, 0, 0);
+  cairo_save(_ct);
+  cairo_set_operator(_ct, CAIRO_OPERATOR_SOURCE);
+  tstruct = [matrix transformStruct];
+
+  cairo_matrix_init(&local_matrix,
+		    tstruct.m11, tstruct.m12,
+		    tstruct.m21, tstruct.m22, 
+		    tstruct.tX, tstruct.tY);
+  cairo_transform(_ct, &local_matrix);
   if (_viewIsFlipped)
     {
-      cairo_rectangle(_ct, 0, -pixelsHigh, pixelsWide, pixelsHigh);
+      cairo_pattern_t *pattern;
+      cairo_matrix_t local_matrix;
+      
+      pattern = cairo_pattern_create_for_surface (surface);
+      cairo_matrix_init_scale(&local_matrix, 1, -1);
+      cairo_matrix_translate(&local_matrix, 0, -2*pixelsHigh);
+      cairo_pattern_set_matrix(pattern, &local_matrix);
+      cairo_set_source(_ct, pattern);
+      cairo_pattern_destroy(pattern);
+
+      cairo_rectangle(_ct, 0, pixelsHigh, pixelsWide, pixelsHigh);
     }
   else 
     {
+      cairo_pattern_t *pattern;
+      cairo_matrix_t local_matrix;
+      
+      pattern = cairo_pattern_create_for_surface (surface);
+      cairo_matrix_init_scale(&local_matrix, 1, -1);
+      cairo_matrix_translate(&local_matrix, 0, -pixelsHigh);
+      cairo_pattern_set_matrix(pattern, &local_matrix);
+      cairo_set_source(_ct, pattern);
+      cairo_pattern_destroy(pattern);
+
       cairo_rectangle(_ct, 0, 0, pixelsWide, pixelsHigh);
     }
   cairo_fill(_ct);
   cairo_surface_destroy(surface);
   cairo_restore(_ct);
+
+  if (bits != data[0])
+    {
+      objc_free((unsigned char *)bits);
+    }
 }
 
 - (void) compositerect: (NSRect)aRect op: (NSCompositingOperation)op
 {
+  cairo_save(_ct);
   _set_op(_ct, op);
   cairo_rectangle(_ct, NSMinX(aRect), NSMinY(aRect), NSWidth(aRect),
 		  NSHeight(aRect));
   cairo_fill(_ct);
+  cairo_restore(_ct);
 }
 
 - (void) compositeGState: (CairoGState *)source 
@@ -1152,6 +1238,11 @@ _set_op(cairo_t * ct, NSCompositingOperation op)
   _set_op(_ct, op);
 
   src = cairo_get_target(source->_ct);
+  if (src == cairo_get_target(_ct))
+    {
+      //NSLog(@"Copy onto self");
+    }
+
   minx = NSMinX(aRect);
   miny = NSMinY(aRect);
   width = NSWidth(aRect);
@@ -1163,12 +1254,50 @@ _set_op(cairo_t * ct, NSCompositingOperation op)
   cairo_device_to_user_distance(_ct, &width, &height);
   NSLog(@"Rect %@  = %f, %f, %f, %f", NSStringFromRect(aRect), minx, miny, width, height);
   */
-  cairo_set_source_surface(_ct, src, aPoint.x - minx, aPoint.y - miny);
-  cairo_rectangle (_ct, aPoint.x, aPoint.y, width, height);
+  if (_viewIsFlipped)
+    {
 /*
-  cairo_set_source_surface(_ct, src, aPoint.x - NSMinX(aRect), aPoint.y - NSMinY(aRect));
-  cairo_rectangle (_ct, aPoint.x, aPoint.y, NSWidth(aRect), NSHeight(aRect));
+      if (!source->_viewIsFlipped)
+        {
+	  // Undo flipping of the source coordinate system
+	  cairo_pattern_t *pattern;
+	  cairo_matrix_t local_matrix;
+	  
+	  pattern = cairo_pattern_create_for_surface(src);
+	  cairo_matrix_init_scale(&local_matrix, 1, -1);
+	  cairo_matrix_translate(&local_matrix, -aPoint.x + minx, -aPoint.y + miny);
+	  cairo_pattern_set_matrix(pattern, &local_matrix);
+	  cairo_set_source(_ct, pattern);
+	  cairo_pattern_destroy(pattern);
+	}
+      else 
 */
+        {
+	  cairo_set_source_surface(_ct, src, aPoint.x - minx, aPoint.y - miny - height);
+	}
+      cairo_rectangle (_ct, aPoint.x, aPoint.y - height, width, height);
+    }
+  else 
+    {
+      if (!source->_viewIsFlipped)
+        {
+	  // Undo flipping of the source coordinate system
+	  cairo_pattern_t *pattern;
+	  cairo_matrix_t local_matrix;
+	  
+	  pattern = cairo_pattern_create_for_surface(src);
+	  cairo_matrix_init_scale(&local_matrix, 1, -1);
+	  cairo_matrix_translate(&local_matrix, -aPoint.x + minx, -aPoint.y + miny - height);
+	  cairo_pattern_set_matrix(pattern, &local_matrix);
+	  cairo_set_source(_ct, pattern);
+	  cairo_pattern_destroy(pattern);
+	}
+      else
+        {
+	  cairo_set_source_surface(_ct, src, aPoint.x - minx, aPoint.y - miny);
+	}
+      cairo_rectangle (_ct, aPoint.x, aPoint.y, width, height);
+    }
 
   if (delta < 1.0)
   {
