@@ -2,7 +2,9 @@
 
    Copyright (C) 2002 Free Software Foundation, Inc.
 
-   Written by: <author name="Fred Kiefer><email>FredKiefer@gmx.de</email></author>
+   Written by: Fred Kiefer <FredKiefer@gmx.de>
+   Additions by: Christopher Armstrong <carmstrong@fastmail.com.au>
+
    Date: March 2002
    
    This file is part of the GNU Objective C User Interface Library.
@@ -19,7 +21,8 @@
    
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
    */
 
 // Currently the use of alpha blending is switched off by default.
@@ -86,8 +89,8 @@ POINT GSWindowPointToMS(WIN32GState *s, NSPoint p)
   p.x += s->offset.x;
   p.y += s->offset.y;
   p1.x = p.x;
-  p1.y = h -p.y;
-
+  p1.y = h - p.y;
+  
   return p1;
 }
 
@@ -214,10 +217,11 @@ RECT GSXWindowRectToMS(WIN32GState *s, NSRect r)
   int x;
   int y;
   NSRect destRect;
-  BOOL success;
+  BOOL success = NO;
 
-  NSDebugLLog(@"WIN32GState", @"compositeGState: fromRect: %@ toPoint: %@ op: %d",
-	      NSStringFromRect(sourceRect), NSStringFromPoint(destPoint), op);
+  NSDebugLLog(@"WIN32GState",
+    @"compositeGState: fromRect: %@ toPoint: %@ op: %d",
+    NSStringFromRect(sourceRect), NSStringFromPoint(destPoint), op);
 
   rectFrom = GSViewRectToWin(source, sourceRect);
   //rectFrom = GSXWindowRectToMS(sourceRect);
@@ -259,8 +263,9 @@ RECT GSXWindowRectToMS(WIN32GState *s, NSRect r)
       {
 #ifdef USE_ALPHABLEND
 	// Use (0..1) fraction to set a (0..255) alpha constant value
-	BYTE SourceCosntantAlpha = (BYTE)(delta * 255);
-	BLENDFUNCTION blendFunc = {AC_SRC_OVER, 0, SourceCosntantAlpha, AC_SRC_ALPHA};
+	BYTE SourceConstantAlpha = (BYTE)(delta * 255);
+	BLENDFUNCTION blendFunc
+	  = {AC_SRC_OVER, 0, SourceConstantAlpha, AC_SRC_ALPHA};
 	success = AlphaBlend(hDC,
 			     x, y, (rectFrom.right - rectFrom.left), h,
 			     sourceDC,
@@ -273,7 +278,16 @@ RECT GSXWindowRectToMS(WIN32GState *s, NSRect r)
 	  break;
 #endif
       }
-
+    case NSCompositeCopy:
+      {
+	success = BitBlt(hDC, x, y, (rectFrom.right - rectFrom.left), h,
+			sourceDC, rectFrom.left, rectFrom.top, SRCCOPY);
+	break;	      
+      }
+    case NSCompositeClear:
+      {
+	break;
+      }
     default:
       success = BitBlt(hDC, x, y, (rectFrom.right - rectFrom.left), h,
 			sourceDC, rectFrom.left, rectFrom.top, SRCCOPY);
@@ -333,40 +347,40 @@ RECT GSXWindowRectToMS(WIN32GState *s, NSRect r)
 
   switch (op)
     {
-    case   NSCompositeClear:
-      break;
-    case   NSCompositeHighlight:
-      {
-	HDC hDC;
-	RECT rect = GSViewRectToWin(self, aRect);
+      case   NSCompositeClear:
+	break;
+      case   NSCompositeHighlight:
+	{
+	  HDC hDC;
+	  RECT rect = GSViewRectToWin(self, aRect);
 
-	hDC = [self getHDC];
-	if (!hDC)
-	  {
-	    return;
-	  } 
+	  hDC = [self getHDC];
+	  if (!hDC)
+	    {
+	      return;
+	    } 
 
-	InvertRect(hDC, &rect);
-	[self releaseHDC: hDC];
+	  InvertRect(hDC, &rect);
+	  [self releaseHDC: hDC];
+	  break;
+	}
+      case   NSCompositeCopy:
+      // FIXME
+      case   NSCompositeSourceOver:
+      case   NSCompositeSourceIn:
+      case   NSCompositeSourceOut:
+      case   NSCompositeSourceAtop:
+      case   NSCompositeDestinationOver:
+      case   NSCompositeDestinationIn:
+      case   NSCompositeDestinationOut:
+      case   NSCompositeDestinationAtop:
+      case   NSCompositeXOR:
+      case   NSCompositePlusDarker:
+      case   NSCompositePlusLighter:
+      default:
+	[self DPSrectfill: NSMinX(aRect) : NSMinY(aRect) 
+	      : NSWidth(aRect) : NSHeight(aRect)];
 	break;
-      }
-    case   NSCompositeCopy:
-    // FIXME
-    case   NSCompositeSourceOver:
-    case   NSCompositeSourceIn:
-    case   NSCompositeSourceOut:
-    case   NSCompositeSourceAtop:
-    case   NSCompositeDestinationOver:
-    case   NSCompositeDestinationIn:
-    case   NSCompositeDestinationOut:
-    case   NSCompositeDestinationAtop:
-    case   NSCompositeXOR:
-    case   NSCompositePlusDarker:
-    case   NSCompositePlusLighter:
-    default:
-      [self DPSrectfill: NSMinX(aRect) : NSMinY(aRect) 
-	    : NSWidth(aRect) : NSHeight(aRect)];
-      break;
     }
 }
 
@@ -386,10 +400,12 @@ HBITMAP GSCreateBitmap(HDC hDC, int pixelsWide, int pixelsHigh,
   int xres, yres;
   UINT fuColorUse;
 
-  if (isPlanar || !([colorSpaceName isEqualToString: NSDeviceRGBColorSpace] ||
-		    [colorSpaceName isEqualToString: NSCalibratedRGBColorSpace]))
+  if (isPlanar
+    || !([colorSpaceName isEqualToString: NSDeviceRGBColorSpace]
+    || [colorSpaceName isEqualToString: NSCalibratedRGBColorSpace]))
     {
-      NSLog(@"Bitmap type currently not supported %d %@", isPlanar, colorSpaceName);
+      NSLog(@"Bitmap type currently not supported %d %@",
+	isPlanar, colorSpaceName);
       return NULL;
     }
 
@@ -478,6 +494,33 @@ HBITMAP GSCreateBitmap(HDC hDC, int pixelsWide, int pixelsHigh,
 	}
       bits = tmp;
     }
+  else if (bitsPerPixel == 24)
+   {
+      unsigned char* tmp;
+      unsigned int pixels = pixelsHigh * pixelsWide;
+      unsigned int i = 0, j = 0;
+ 
+      bmih->biBitCount = 32;
+
+      NSDebugLLog(@"WIN32GState", @"24bit picure with pixelsWide:%d "
+	@"pixelsHigh:%d", pixelsWide, pixelsHigh);
+      
+      tmp = objc_malloc(pixels * 4);
+      //memset(tmp, 0xFF, pixels*4);
+      while (i < (pixels*4))
+        {
+          // We expand the bytes in a 24bit image into 32bits as Windows
+	  // seems to handle it better (and I can't figure out the correct
+	  // rearrangement for 24bit images anyway).
+          tmp[i+0] = bits[j+2];
+          tmp[i+1] = bits[j+1];
+          tmp[i+2] = bits[j+0];
+          tmp[i+3] = 0xFF;
+	  i+=4;
+          j+=3;
+        }
+      bits = tmp;
+    }
   else if (bitsPerPixel == 16)
     {
 /*
@@ -819,18 +862,16 @@ HBITMAP GSCreateBitmap(HDC hDC, int pixelsWide, int pixelsHigh,
 - (void)DPSrectstroke: (float)x : (float)y : (float)w : (float)h 
 {
   NSRect rect = [ctm rectInMatrixSpace: NSMakeRect(x, y, w, h)]; 
-  NSBezierPath *oldPath = path;
 
-  // Samll adjustment so that the line is visible
+  /* // Samll adjustment so that the line is visible
   if (rect.size.width > 0)
     rect.size.width--;
   if (rect.size.height > 0)
     rect.size.height--;
-  rect.origin.y += 1;
+  rect.origin.y += 1; */
 
-  path = [NSBezierPath bezierPathWithRect: rect];
+  [path appendBezierPathWithRect: rect];
   [self DPSstroke];
-  path = oldPath;
 }
 
 - (void)DPSrectclip: (float)x : (float)y : (float)w : (float)h 
@@ -865,7 +906,7 @@ HBITMAP GSCreateBitmap(HDC hDC, int pixelsWide, int pixelsHigh,
     } 
 
   p = GSWindowPointToMS(self, current);
-  [(WIN32FontInfo*)font draw: s lenght:  strlen(s)
+  [(WIN32FontInfo*)font draw: s length:  strlen(s)
 		   onDC: hDC at: p];
   [self releaseHDC: hDC];
 }
@@ -970,6 +1011,12 @@ HBITMAP GSCreateBitmap(HDC hDC, int pixelsWide, int pixelsHigh,
   int cap;
   DWORD penStyle;
 
+  // Temporary variables for gathering pen information
+  float* thePattern = NULL;
+  DWORD* iPattern = NULL;
+  int patternCount = 0;
+  float phase = 0.0;
+  
   SetBkMode(hDC, TRANSPARENT);
   br.lbStyle = BS_SOLID;
   br.lbColor = wfcolor;
@@ -982,55 +1029,71 @@ HBITMAP GSCreateBitmap(HDC hDC, int pixelsWide, int pixelsHigh,
 
   switch (joinStyle)
     {
-    case NSBevelLineJoinStyle:
-      join = PS_JOIN_BEVEL;
-      break;
-    case NSMiterLineJoinStyle:
-      join = PS_JOIN_MITER;
-      break;
-    case NSRoundLineJoinStyle:
-      join = PS_JOIN_ROUND;
-      break;
-    default:
-      join = PS_JOIN_MITER;
-      break;
+      case NSBevelLineJoinStyle:
+	join = PS_JOIN_BEVEL;
+	break;
+      case NSMiterLineJoinStyle:
+	join = PS_JOIN_MITER;
+	break;
+      case NSRoundLineJoinStyle:
+	join = PS_JOIN_ROUND;
+	break;
+      default:
+	join = PS_JOIN_MITER;
+	break;
     }
 
   switch (lineCap)
     {
-    case NSButtLineCapStyle:
-      cap = PS_ENDCAP_FLAT;
-      break;
-    case NSSquareLineCapStyle:
-      cap = PS_ENDCAP_SQUARE;
-      break;
-    case NSRoundLineCapStyle:
-      cap = PS_ENDCAP_ROUND;
-      break;
-    default:
-      cap = PS_ENDCAP_SQUARE;
-      break;
+      case NSButtLineCapStyle:
+	cap = PS_ENDCAP_FLAT;
+	break;
+      case NSSquareLineCapStyle:
+	cap = PS_ENDCAP_SQUARE;
+	break;
+      case NSRoundLineCapStyle:
+	cap = PS_ENDCAP_ROUND;
+	break;
+      default:
+	cap = PS_ENDCAP_SQUARE;
+	break;
     }
-
-  penStyle = PS_GEOMETRIC | PS_SOLID;
-  if (path)
+  
+  // Get the size of the pen line dash
+  [path getLineDash: NULL count: &patternCount phase: NULL];
+  
+  if (patternCount > 0)
     {
-      float thePattern[10];
-      int count = 10;
-      float phase;
+      penStyle = PS_GEOMETRIC | PS_USERSTYLE;
 
-      [path getLineDash: thePattern count: &count phase: &phase];
+      // The user has defined a dash pattern for stroking on
+      // the path. Note that we lose the floating point information
+      // here, as windows only supports DWORD elements, not float.
+      thePattern = objc_malloc(sizeof(float) * patternCount);
+      [path getLineDash: thePattern count: &patternCount phase: &phase];
 
-      if (count && (count < 10))
-	{
-	  penStyle = PS_GEOMETRIC | PS_DASH;
-	}
+      iPattern = objc_malloc(sizeof(DWORD) * patternCount);
+      int i  = 0;
+      for (i = 0 ; i < patternCount; i ++)
+	iPattern[i] = (DWORD)thePattern[i];
+      objc_free(thePattern);
+      thePattern = NULL;
+    }
+  else
+    {
+      penStyle = PS_GEOMETRIC | PS_SOLID;
     }
 
   pen = ExtCreatePen(penStyle | join | cap, 
 		     lineWidth,
 		     &br,
-		     0, NULL);
+		     patternCount, iPattern);
+
+  if (iPattern)
+    {
+      objc_free(iPattern);
+      iPattern = NULL;
+    }
 
   oldPen = SelectObject(hDC, pen);
 
