@@ -39,6 +39,14 @@
 #include <Foundation/NSUserDefaults.h>
 #include <Foundation/NSDebug.h>
 
+#include <signal.h>
+/* Terminate cleanly if we get a signal to do so */
+static void
+terminate(int sig)
+{
+  [NSApp terminate: NSApp];
+}
+
 #ifdef HAVE_WRASTER_H
 #include "wraster.h"
 #else
@@ -347,6 +355,7 @@ _parse_display_name(NSString *name, int *dn, int *sn)
 {
   NSDebugLog(@"Initializing GNUstep x11 backend.\n");
   [GSDisplayServer setDefaultServerClass: [XGServer class]];
+  signal(SIGTERM, terminate);
 }
 
 /**
@@ -361,15 +370,16 @@ _parse_display_name(NSString *name, int *dn, int *sn)
 - _initXContext
 {
   int			screen_number, display_number;
-  NSString		*display_name, *host;
+  NSString		*display_name;
   XGScreenContext       *screen;
 
-  host = [[NSUserDefaults standardUserDefaults] stringForKey: @"NSHost"];
   display_name = [server_info objectForKey: GSDisplayName];
   if (display_name == nil)
     {
+      NSString *host = [[NSUserDefaults standardUserDefaults] stringForKey: @"NSHost"];
       NSString *dn = [server_info objectForKey: GSDisplayNumber];
       NSString *sn = [server_info objectForKey: GSScreenNumber];
+
       if (dn || sn)
 	{
 	  if (dn == NULL)
@@ -380,35 +390,8 @@ _parse_display_name(NSString *name, int *dn, int *sn)
 	    host = @"";
 	  display_name = [NSString stringWithFormat: @"%@:%@.%@", host, dn,sn];
 	}
-    }
-
-  if (display_name == nil)
-    {
-      if (host == nil)
-	{
-	  NSString	*d = [[[NSProcessInfo processInfo] environment]
-	    objectForKey: @"DISPLAY"];
-
-	  host = _parse_display_name(d, &display_number, &screen_number);
-	  if (display_number != 0)
-	    {
-	      NSLog(@"NOTE: Only one display per host fully supported.");
-	    }
-	  if ([host isEqual: @""] == NO)
-	    {
-	      /**
-	       * If we are using the DISPLAY environment variable to
-	       * determine where to display, set the NSHost default
-	       * so that other parts of the system know where we are
-	       * displaying.
-	       */
-	      [[NSUserDefaults standardUserDefaults] registerDefaults:
-		  [NSDictionary dictionaryWithObject: host
-			                      forKey: @"NSHost"]];
-	    }
-	}
-      else if ([host isEqual: @""] == NO)
-	{
+      else if ((host != nil) && ([host isEqual: @""] == NO))
+        {
 	  /**
 	   * If the NSHost default told us to display somewhere, we need
 	   * to generate a display name for X from the host name and the
@@ -452,7 +435,7 @@ _parse_display_name(NSString *name, int *dn, int *sn)
 
   screen = [[XGScreenContext alloc] initForDisplay: dpy screen: screen_number];
   AUTORELEASE(screen);
-  NSMapInsert(screenList, (void *)screen_number, (void *)screen);
+  NSMapInsert(screenList, (void *)(uintptr_t)screen_number, (void *)screen);
   defScreen = screen_number;
 
   XSetErrorHandler(XGErrorHandler);
@@ -514,14 +497,14 @@ _parse_display_name(NSString *name, int *dn, int *sn)
 		   format: @"Request for invalid screen"];
     }
 
-  screen = NSMapGet(screenList, (void *)screen_number);
+  screen = NSMapGet(screenList, (void *)(uintptr_t)screen_number);
   if (screen == NULL)
     {
       XGScreenContext *screen;
       screen = [[XGScreenContext alloc] 
 		 initForDisplay: dpy screen: screen_number];
       AUTORELEASE(screen);
-      NSMapInsert(screenList, (void *)screen_number, (void *)screen);
+      NSMapInsert(screenList, (void *)(uintptr_t)screen_number, (void *)screen);
     }
   return screen;
 }
@@ -622,12 +605,14 @@ _parse_display_name(NSString *name, int *dn, int *sn)
 @implementation XGServer (InputMethod)
 - (NSString *) inputMethodStyle
 {
-  return inputServer ? [(XIMInputServer *)inputServer inputMethodStyle] : nil;
+  return inputServer ? [(XIMInputServer *)inputServer inputMethodStyle]
+    : (NSString*)nil;
 }
 
 - (NSString *) fontSize: (int *)size
 {
-  return inputServer ? [(XIMInputServer *)inputServer fontSize: size] : nil;
+  return inputServer ? [(XIMInputServer *)inputServer fontSize: size]
+    : (NSString*)nil;
 }
 
 - (BOOL) clientWindowRect: (NSRect *)rect
