@@ -93,6 +93,12 @@ void __objc_xgcontextevent_linking (void)
 static SEL    procSel = 0;
 static void (*procEvent)(id, SEL, XEvent*) = 0;
 
+#ifdef XSHM
+@interface NSGraphicsContext (SharedMemory)
+-(void) gotShmCompletion: (Drawable)d;
+@end
+#endif
+
 @interface XGServer (Private)
 - (void) receivedEvent: (void*)data
                   type: (RunLoopEventType)type
@@ -542,6 +548,14 @@ static int check_modifier (XEvent *xEvent, KeySym key_sym,
 		    e = [self _handleTakeFocusAtom: xEvent 
 			                forContext: gcontext];
 		  }
+		else if ((Atom)xEvent.xclient.data.l[0]
+			 == generic.net_wm_ping_atom)
+		  {
+		    xEvent.xclient.window = RootWindow(dpy, cWin->screen);
+		    XSendEvent(dpy, xEvent.xclient.window, False, 
+			       (SubstructureRedirectMask | SubstructureNotifyMask), 
+			       &xEvent);
+		  }
 	      }
 	    else if (xEvent.xclient.message_type == dnd.XdndEnter)
 	      {
@@ -764,7 +778,7 @@ static int check_modifier (XEvent *xEvent, KeySym key_sym,
 	      /*
 	       * Set size hints info to be up to date with new size.
 	       */
-	      h = [self _OSFrameToXHints: n for: cWin];
+	      h = [self _XFrameToXHints: x for: cWin];
 	      cWin->siz_hints.width = h.size.width;
 	      cWin->siz_hints.height = h.size.height;
 
