@@ -67,7 +67,7 @@ static BOOL handlesWindowDecorations = YES;
  */
 static char	*rootName = 0;
 
-#define WINDOW_WITH_TAG(windowNumber) (gswindow_device_t *)NSMapGet(windowtags, (void *)windowNumber) 
+#define WINDOW_WITH_TAG(windowNumber) (gswindow_device_t *)NSMapGet(windowtags, (void *)(uintptr_t)windowNumber) 
 
 /* Current mouse grab window */
 static gswindow_device_t *grab_window = NULL;
@@ -184,7 +184,7 @@ typedef struct {
   unsigned long flags;
   unsigned long functions;
   unsigned long decorations;
-  long input_mode;
+  unsigned long input_mode;
   unsigned long status;
 } MwmHints;
 
@@ -245,7 +245,7 @@ static void setWindowHintsForStyle (Display *dpy, Window window,
   
   /* Get the already-set window hints */
   success = XGetWindowProperty (dpy, window, mwhints_atom, 0, 
-		      sizeof (MwmHints) / sizeof (long),
+		      sizeof (MwmHints) / sizeof (unsigned long),
 		      False, AnyPropertyType, &type_ret, &format_ret, 
 		      &nitems_ret, &bytes_after_ret, 
 		      (unsigned char **)&hints);
@@ -331,7 +331,7 @@ static void setWindowHintsForStyle (Display *dpy, Window window,
   /* Set the hints */
   XChangeProperty (dpy, window, mwhints_atom, mwhints_atom, 32, 
 		   PropModeReplace, (unsigned char *)hints, 
-		   sizeof (MwmHints) / sizeof (long));
+		   sizeof (MwmHints) / sizeof (unsigned long));
   
   /* Free the hints if allocated by the X server for us */
   if (needToFreeHints == YES)
@@ -353,6 +353,11 @@ static void setWindowHintsForStyle (Display *dpy, Window window,
 }
 @end
 
+@interface XGServer (WindowOps)
+- (void) styleoffsets: (float *) l : (float *) r : (float *) t : (float *) b
+                     : (unsigned int) style : (Window) win;
+@end
+
 @implementation XGServer (WindowOps)
 
 -(BOOL) handlesWindowDecorations
@@ -368,11 +373,11 @@ static void setWindowHintsForStyle (Display *dpy, Window window,
 + (gswindow_device_t *) _windowForXParent: (Window)xWindow
 {
   NSMapEnumerator	enumerator;
-  Window		x;
+  void		*key;
   gswindow_device_t	*d;
 
   enumerator = NSEnumerateMapTable(windowmaps);
-  while (NSNextMapEnumeratorPair(&enumerator, (void**)&x, (void**)&d) == YES)
+  while (NSNextMapEnumeratorPair(&enumerator, &key, (void**)&d) == YES)
     {
       if (d->root != d->parent && d->parent == xWindow)
 	{
@@ -405,8 +410,8 @@ static void setWindowHintsForStyle (Display *dpy, Window window,
   x = o;
   x.origin.y = x.origin.y + o.size.height;
   x.origin.y = DisplayHeight(dpy, win->screen) - x.origin.y;
-NSDebugLLog(@"Frame", @"O2X %d, %@, %@", win->number,
-  NSStringFromRect(o), NSStringFromRect(x));
+  NSDebugLLog(@"Frame", @"O2X %d, %@, %@", win->number,
+	      NSStringFromRect(o), NSStringFromRect(x));
   return x;
 }
 
@@ -420,15 +425,15 @@ NSDebugLLog(@"Frame", @"O2X %d, %@, %@", win->number,
   NSRect	x;
   float	t, b, l, r;
 
-  [self styleoffsets: &l : &r : &t : &b : win->win_attrs.window_style];
+  [self styleoffsets: &l : &r : &t : &b : win->win_attrs.window_style : win->ident];
 
   x.size.width = o.size.width;
   x.size.height = o.size.height;
   x.origin.x = o.origin.x - l;
   x.origin.y = o.origin.y + o.size.height;
   x.origin.y = DisplayHeight(dpy, win->screen) - x.origin.y - t;
-NSDebugLLog(@"Frame", @"O2H %d, %@, %@", win->number,
-  NSStringFromRect(o), NSStringFromRect(x));
+  NSDebugLLog(@"Frame", @"O2H %d, %@, %@", win->number,
+	      NSStringFromRect(o), NSStringFromRect(x));
   return x;
 }
 
@@ -445,7 +450,7 @@ NSDebugLLog(@"Frame", @"O2H %d, %@, %@", win->number,
   o.origin.x = x.origin.x;
   o.origin.y = win->siz_hints.height - x.origin.y;
   o.origin.y = o.origin.y - o.size.height;
-  NSDebugLLog(@"GGFrame", @"%@ %@", NSStringFromRect(x), NSStringFromRect(o));
+  NSDebugLLog(@"Frame", @"X2O %@ %@", NSStringFromRect(x), NSStringFromRect(o));
   return o;
 }
 
@@ -462,11 +467,33 @@ NSDebugLLog(@"Frame", @"O2H %d, %@, %@", win->number,
   o = x;
   o.origin.y = DisplayHeight(dpy, win->screen) - o.origin.y;
   o.origin.y = o.origin.y - o.size.height;
-NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
-  NSStringFromRect(x), NSStringFromRect(o));
+  NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
+	      NSStringFromRect(x), NSStringFromRect(o));
   return o;
 }
 
+/*
+ * Convert a window frame in X absolute screen coordinates to
+ * a frame suitable for setting X hints for a window manager.
+ */
+- (NSRect) _XFrameToXHints: (NSRect)o for: (void*)window
+{
+  gswindow_device_t	*win = (gswindow_device_t*)window;
+  NSRect	x;
+  float	t, b, l, r;
+
+  [self styleoffsets: &l : &r : &t : &b : win->win_attrs.window_style : win->ident];
+
+  // FIXME: When adding the frame here, we get X window errors!
+  x.size.width = o.size.width; // + l + r;
+  x.size.height = o.size.height; // + t + b;
+  x.origin.x = o.origin.x - l;
+  x.origin.y = o.origin.y - t;
+  NSDebugLLog(@"Frame", @"X2H %d, %@, %@", win->number,
+	      NSStringFromRect(o), NSStringFromRect(x));
+  return x;
+}
+
 
 - (XGWMProtocols) _checkWindowManager
 {
@@ -758,6 +785,7 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
   generic.protocols_atom = XInternAtom(dpy, "WM_PROTOCOLS", False);
   generic.take_focus_atom = XInternAtom(dpy, "WM_TAKE_FOCUS", False);
   generic.delete_win_atom = XInternAtom(dpy, "WM_DELETE_WINDOW", False);
+  generic.net_wm_ping_atom = XInternAtom(dpy, "_NET_WM_PING", False);
   generic.miniaturize_atom
     = XInternAtom(dpy, "_GNUSTEP_WM_MINIATURIZE_WINDOW", False);
   generic.win_decor_atom = XInternAtom(dpy,"_GNUSTEP_WM_ATTR", False);
@@ -877,6 +905,10 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
      */
     win_attrs.flags = GSExtraFlagsAttr;
     win_attrs.extra_flags = GSNoApplicationIconFlag;
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
     XChangeProperty(dpy, ROOT,
 	generic.win_decor_atom, generic.win_decor_atom,
 	32, PropModeReplace, (unsigned char *)&win_attrs,
@@ -887,8 +919,12 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
     {
       // Store the id of our process
       Atom pid_atom = XInternAtom(dpy, "_NET_WM_PID", False);
-      int pid = [pInfo processIdentifier];
+      long pid = [pInfo processIdentifier];
 
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
       XChangeProperty(dpy, ROOT,
 		      pid_atom, XA_CARDINAL,
 		      32, PropModeReplace, 
@@ -900,7 +936,7 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
    this context */
 - (void) _destroyServerWindows
 {
-  int num;
+  void *key;
   gswindow_device_t *d;
   NSMapEnumerator   enumerator;
   NSMapTable        *mapcopy;
@@ -909,10 +945,10 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
      the map table */
   mapcopy = NSCopyMapTableWithZone(windowtags, [self zone]);
   enumerator = NSEnumerateMapTable(mapcopy);
-  while (NSNextMapEnumeratorPair(&enumerator, (void**)&num, (void**)&d) == YES)
+  while (NSNextMapEnumeratorPair(&enumerator, &key, (void**)&d) == YES)
     {
       if (d->display == dpy && d->ident != d->root)
-	[self termwindow: num];
+	[self termwindow: (int)(intptr_t)key];
     }
   NSFreeMapTable(mapcopy);
 }
@@ -1077,11 +1113,13 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
       if (image != nil)
         {
 	  didCreateNetIcon = YES;
-	  [self _createNetIcon: image result: &iconPropertyData size: &iconSize];
+	  [self _createNetIcon: image
+			result: &iconPropertyData
+			  size: &iconSize];
 	}
     }
 
-  if (iconPropertyData)
+  if (iconPropertyData != 0)
     {
       XChangeProperty(dpy, window,
 		      icon_atom, XA_CARDINAL, 
@@ -1185,8 +1223,7 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
    * Prepare size/position hints, but don't set them now - ordering
    * the window in should automatically do it.
    */
-  frame = [self _XFrameToOSFrame: window->xframe for: window];
-  frame = [self _OSFrameToXHints: frame for: window];
+  frame = [self _XFrameToXHints: window->xframe for: window];
   window->siz_hints.x = NSMinX(frame);
   window->siz_hints.y = NSMinY(frame);
   window->siz_hints.width = NSWidth(frame);
@@ -1194,6 +1231,10 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
   window->siz_hints.flags = USPosition|PPosition|USSize|PSize;
 
   // Always send GNUstepWMAttributes
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
   XChangeProperty(dpy, window->ident, generic.win_decor_atom, 
 		      generic.win_decor_atom, 32, PropModeReplace, 
 		      (unsigned char *)&window->win_attrs,
@@ -1227,6 +1268,7 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
   window->numProtocols = 0;
   window->protocols[window->numProtocols++] = generic.take_focus_atom;
   window->protocols[window->numProtocols++] = generic.delete_win_atom;
+  window->protocols[window->numProtocols++] = generic.net_wm_ping_atom;
   if ((generic.wm & XGWM_WINDOWMAKER) != 0)
     {
       window->protocols[window->numProtocols++] = generic.miniaturize_atom;
@@ -1261,6 +1303,122 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
   return window->number;
 }
 
+- (int) nativeWindow: (void *)winref : (NSRect*)frame : (NSBackingStoreType*)type 
+		    : (unsigned int*)style : (int*)screen
+{
+  static int		last_win_num = 0;
+  gswindow_device_t	*window;
+  gswindow_device_t	*root;
+  XGCValues		values;
+  unsigned long		valuemask;
+  RContext              *context;
+  XWindowAttributes win_attributes;
+  Window windowRef;
+  NSRect xframe;
+
+  windowRef = *((Window*)winref);
+  NSDebugLLog(@"XGTrace", @"nativeWindow: %d", windowRef);
+  if (!XGetWindowAttributes(dpy, windowRef, &win_attributes))
+    {
+      return 0;
+    }
+
+  *screen = XScreenNumberOfScreen(win_attributes.screen);
+  *type = NSBackingStoreNonretained;
+  *style = NSBorderlessWindowMask;
+  root = [self _rootWindowForScreen: *screen];
+  context = [self xrContextForScreen: *screen];
+
+  /* Create the window structure and set the style early so we can use it to
+  convert frames. */
+  window = objc_malloc(sizeof(gswindow_device_t));
+  memset(window, '\0', sizeof(gswindow_device_t));
+  window->display = dpy;
+  window->screen = *screen;
+  window->ident = windowRef;
+  window->root = root->ident;
+  window->parent = root->ident;
+  window->type = *type;
+  window->win_attrs.flags |= GSWindowStyleAttr;
+  window->win_attrs.window_style = *style;
+
+  window->border = win_attributes.border_width;
+  window->depth = win_attributes.depth;
+  window->xframe = NSMakeRect(win_attributes.x, win_attributes.y, 
+			      win_attributes.width, win_attributes.height);
+  window->xwn_attrs.colormap = win_attributes.colormap;
+  window->xwn_attrs.save_under = win_attributes.save_under;
+  window->xwn_attrs.override_redirect = win_attributes.override_redirect;
+  window->map_state = win_attributes.map_state;
+
+  window->xwn_attrs.border_pixel = context->black;
+  window->xwn_attrs.background_pixel = context->white;
+  window->visibility = -1;
+
+  // Create an X GC for the content view set it's colors
+  values.foreground = window->xwn_attrs.background_pixel;
+  values.background = window->xwn_attrs.background_pixel;
+  values.function = GXcopy;
+  valuemask = (GCForeground | GCBackground | GCFunction);
+  window->gc = XCreateGC(dpy, window->ident, valuemask, &values);
+
+  /*
+   * Initial attributes for any GNUstep window tell Window Maker not to
+   * create an app icon for us.
+   */
+  window->win_attrs.flags |= GSExtraFlagsAttr;
+  window->win_attrs.extra_flags |= GSNoApplicationIconFlag;
+
+  /*
+   * Prepare size/position hints, but don't set them now - ordering
+   * the window in should automatically do it.
+   */
+  *frame = [self _XFrameToOSFrame: window->xframe for: window];
+
+  // Use the globally active input mode
+  window->gen_hints.flags = InputHint;
+  window->gen_hints.input = False;
+  // All the windows of a GNUstep application belong to one group.
+  window->gen_hints.flags |= WindowGroupHint;
+  window->gen_hints.window_group = ROOT;
+  window->exposedRects = [NSMutableArray new];
+  window->region = XCreateRegion();
+  window->buffer = 0;
+  window->alpha_buffer = 0;
+  window->ic = 0;
+
+  /*
+   * Prepare size/position hints, but don't set them now - ordering
+   * the window in should automatically do it.
+   */
+  xframe = [self _XFrameToXHints: window->xframe for: window];
+  window->siz_hints.x = NSMinX(xframe);
+  window->siz_hints.y = NSMinY(xframe);
+  window->siz_hints.width = NSWidth(xframe);
+  window->siz_hints.height = NSHeight(xframe);
+  window->siz_hints.flags = USPosition|PPosition|USSize|PSize;
+
+  // make sure that new window has the correct cursor
+  [self _initializeCursorForXWindow: window->ident];
+
+  /*
+   * FIXME - should this be protected by a lock for thread safety?
+   * generate a unique tag for this new window.
+   */
+  do
+    {
+      last_win_num++;
+    }
+  while (last_win_num == 0 || WINDOW_WITH_TAG(last_win_num) != 0);
+  window->number = last_win_num;
+
+  // Insert window into the mapping
+  NSMapInsert(windowmaps, (void*)window->ident, window);
+  NSMapInsert(windowtags, (void*)window->number, window);
+  [self _setWindowOwnedByServer: window->number];
+  return window->number;
+}
+
 - (void) termwindow: (int)win
 {
   gswindow_device_t *window;
@@ -1285,6 +1443,11 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
       XDestroyWindow(dpy, window->ident);
       if (window->gc)
 	XFreeGC (dpy, window->gc);
+      if (generic.cachedWindow != 0 && 
+	  window->ident == ((gswindow_device_t*)(generic.cachedWindow))->ident)
+        {
+	  generic.cachedWindow = 0;
+	}
       NSMapRemove(windowmaps, (void*)window->ident);
     }
 
@@ -1296,7 +1459,7 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
   if (window->region)
     XDestroyRegion (window->region);
   RELEASE(window->exposedRects);
-  NSMapRemove(windowtags, (void*)win);
+  NSMapRemove(windowtags, (void*)(uintptr_t)win);
   objc_free(window);
 }
 
@@ -1307,6 +1470,15 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
 - (void) styleoffsets: (float *) l : (float *) r : (float *) t : (float *) b 
 		     : (unsigned int) style
 {
+  [self styleoffsets: l : r : t : b : style : (Window) 0];
+}
+
+- (void) styleoffsets: (float *) l : (float *) r : (float *) t : (float *) b 
+		     : (unsigned int) style : (Window) win
+{
+  static Atom _net_frame_extents = None;
+  static Atom _kde_frame_strut = None;
+
   if (!handlesWindowDecorations)
     {
       /*
@@ -1318,7 +1490,45 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
       return;
     }
 
-  /* First try to get the offset information that we have obtained from
+  /* First check _NET_FRAME_EXTENTS */
+  if (win  && ((generic.wm & XGWM_EWMH) != 0)) 
+    {
+      int count;
+      unsigned long *extents;
+
+      if (_net_frame_extents == None)
+        {
+	  _net_frame_extents = XInternAtom(dpy, "_NET_FRAME_EXTENTS", False);
+	}
+
+      extents = (unsigned long *)PropGetCheckProperty(dpy, win, _net_frame_extents, 
+						      XA_CARDINAL, 32, 4, &count);
+
+
+      if (!extents) // && (generic.wm & XGWM_KDE)) 
+        {
+	  if (_kde_frame_strut == None)
+	    {
+	      _kde_frame_strut = XInternAtom(dpy, "_KDE_NET_WM_FRAME_STRUT", False);
+	    }
+	  extents = (unsigned long *)PropGetCheckProperty(dpy, win, _kde_frame_strut, 
+							  XA_CARDINAL, 32, 4, &count);
+	}
+
+      if (extents) 
+        {
+	  NSDebugLLog(@"Frame", @"Window %d, left %d, right %d, top %d, bottom %d", 
+		      win, extents[0], extents[1], extents[2], extents[3]);
+	  *l = extents[0];
+	  *r = extents[1];
+	  *t = extents[2];
+	  *b = extents[3];
+	  XFree(extents);
+	  return;
+	}
+    }
+
+  /* Nextt try to get the offset information that we have obtained from
      the WM. This will only work if the application has already created
      a window that has been reparented by the WM. Otherwise we have to
      guess.
@@ -1420,14 +1630,17 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
       window->win_attrs.window_style = style;
 
       /* Fix up hints */
-      h = [self _XFrameToOSFrame: window->xframe for: window];
-      h = [self _OSFrameToXHints: h for: window];
+      h = [self _XFrameToXHints: window->xframe for: window];
       window->siz_hints.x = NSMinX(h);
       window->siz_hints.y = NSMinY(h);
       window->siz_hints.width = NSWidth(h);
       window->siz_hints.height = NSHeight(h);
 
       // send to the WM window style hints
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
       XChangeProperty(dpy, window->ident, generic.win_decor_atom, 
 			  generic.win_decor_atom, 32, PropModeReplace, 
 			  (unsigned char *)&window->win_attrs,
@@ -1515,6 +1728,21 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
 	}
       XSetWMName(dpy, window->ident, &windowName);
       XSetWMIconName(dpy, window->ident, &windowName);
+
+      {
+      /* Set _NET_WM_NAME and _NET_WM_ICON_NAME */
+      Atom _utf8 = XInternAtom (dpy, "UTF8_STRING", False);
+      Atom _net_wm_name = XInternAtom (dpy, "_NET_WM_NAME", False);
+      Atom _net_wm_icon_name = XInternAtom (dpy, "_NET_WM_ICON_NAME", False);
+      char *name = (char *)[window_title UTF8String];
+      XChangeProperty(dpy, window->ident, _net_wm_name, _utf8,
+		      8, PropModeReplace, 
+		      (unsigned char *)name, strlen(name));
+      XChangeProperty(dpy, window->ident, _net_wm_icon_name, _utf8,
+		      8, PropModeReplace, 
+		      (unsigned char *)name, strlen(name));
+      }
+
       XFree(windowName.value);
     }
 }
@@ -1540,6 +1768,10 @@ NSDebugLLog(@"Frame", @"X2O %d, %@, %@", win->number,
 
   // send WindowMaker WM window style hints
   // Always send GNUstepWMAttributes
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
   XChangeProperty(dpy, window->ident,
 	generic.win_decor_atom, generic.win_decor_atom,
 	32, PropModeReplace, (unsigned char *)&window->win_attrs,
@@ -1993,9 +2225,10 @@ static BOOL didCreatePixmaps;
 {
   NSEvent *e;
   NSRect xVal;
+  NSRect xHint;
+  NSRect frame;
   gswindow_device_t *window;
   NSWindow *nswin;
-  NSRect frame;
   BOOL resize = NO;
   BOOL move = NO;
 
@@ -2022,12 +2255,12 @@ static BOOL didCreatePixmaps;
       move = YES;
     }
 
-  xVal = [self _OSFrameToXHints: rect for: window];
-  window->siz_hints.width = (int)xVal.size.width;
-  window->siz_hints.height = (int)xVal.size.height;
-  window->siz_hints.x = (int)xVal.origin.x;
-  window->siz_hints.y = (int)xVal.origin.y;
   xVal = [self _OSFrameToXFrame: rect for: window];
+  xHint = [self _XFrameToXHints: xVal for: window];
+  window->siz_hints.width = (int)xHint.size.width;
+  window->siz_hints.height = (int)xHint.size.height;
+  window->siz_hints.x = (int)xHint.origin.x;
+  window->siz_hints.y = (int)xHint.origin.y;
 
   NSDebugLLog(@"Moving", @"Place %d - o:%@, x:%@", window->number,
     NSStringFromRect(rect), NSStringFromRect(xVal));
@@ -2127,6 +2360,10 @@ static BOOL didCreatePixmaps;
 	 * is not mapped, we have stored the required info for when
 	 * the WM maps it.
 	 */
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
         XChangeProperty(dpy, window->ident,
 	    generic.win_decor_atom, generic.win_decor_atom,
 	    32, PropModeReplace, (unsigned char *)&window->win_attrs,
@@ -2203,6 +2440,10 @@ static BOOL didCreatePixmaps;
 	      data[0] = generic.wintypes.win_desktop_atom;
 	    }
 
+/* Warning ... X-bug .. when we specify 32bit data X actually expects data
+ * of type 'long' or 'unsigned long' even on machines where those types
+ * hold 64bit values.
+ */
 	  XChangeProperty(dpy, window->ident, generic.wintypes.win_type_atom,
 			  XA_ATOM, 32, PropModeReplace, 
 			  (unsigned char *)&data, len);
@@ -2210,7 +2451,7 @@ static BOOL didCreatePixmaps;
       else if ((generic.wm & XGWM_GNOME) != 0)
 	{
 	  XEvent event;
-	  int    flag = WIN_LAYER_NORMAL;
+	  long    flag = WIN_LAYER_NORMAL;
 
 	  if (level == NSDesktopWindowLevel)
 	    flag = WIN_LAYER_DESKTOP;
@@ -2613,7 +2854,7 @@ static BOOL didCreatePixmaps;
     }
   else
     {
-      unsigned int opacity;
+      unsigned long opacity;
 
       opacity = (unsigned int)(alpha * 0xffffffff);
       XChangeProperty(window->display, window->ident, opacity_atom,
@@ -2623,7 +2864,7 @@ static BOOL didCreatePixmaps;
         {
 	  XChangeProperty(window->display, window->parent, opacity_atom,
 			  XA_CARDINAL, 32, PropModeReplace,
-			  (unsigned char*)&opacity, 1L);
+			  (unsigned char*)&opacity, 1);
 	}
     }
 }
@@ -2714,15 +2955,22 @@ static BOOL   cursor_hidden = NO;
 
 - (void) _DPSsetcursor: (Cursor)c : (BOOL)set
 {
-  Window win;
+  void	*key;
   NSMapEnumerator enumerator;
   gswindow_device_t  *d;
+  Window root;
 
   NSDebugLLog (@"NSCursor", @"_DPSsetcursor: cursor = %p, set = %d", c, set);
-  
+
+  root = DefaultRootWindow(dpy);
   enumerator = NSEnumerateMapTable (windowmaps);
-  while (NSNextMapEnumeratorPair (&enumerator, (void**)&win, (void**)&d) == YES)
+  while (NSNextMapEnumeratorPair (&enumerator, &key, (void**)&d) == YES)
     {
+      Window win = (Window)key;
+
+      if (win == root)
+	continue;
+
       if (set)
         XDefineCursor(dpy, win, c);
       else
@@ -3128,6 +3376,7 @@ _computeDepth(int class, int bpp)
   Atom icon_tile_atom;
   Atom rgba_image_atom;
   Window win;
+  Window *pwin;
   int count;
   unsigned char *tile;
   NSImage *iconTileImage;
@@ -3143,13 +3392,14 @@ _computeDepth(int class, int bpp)
   rgba_image_atom = XInternAtom(dpy,"_RGBA_IMAGE", False);
   
   win = DefaultRootWindow(dpy);
-  win = *(Window *)PropGetCheckProperty(dpy, win, noticeboard_atom, XA_WINDOW,
+  pwin = (Window *)PropGetCheckProperty(dpy, win, noticeboard_atom, XA_WINDOW,
 					32, -1, &count);
-  if (win == (Window)NULL) 
+  if (pwin == NULL) 
     return [super iconTileImage];
   
-  tile = PropGetCheckProperty(dpy, win, icon_tile_atom, rgba_image_atom,
+  tile = PropGetCheckProperty(dpy, *pwin, icon_tile_atom, rgba_image_atom,
 			      8, -1, &count);
+  XFree(pwin);
   if (tile == NULL || count < 4)
     return [super iconTileImage];
   
