@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -141,10 +141,12 @@
     {
       [dbuf setLength: BUF_LEN];
 #ifdef HAVE_UTF8
+#ifdef HAVE_XUTF8LOOKUPSTRING
       if (encoding == NSUTF8StringEncoding)
         count = Xutf8LookupString(windev->ic, event, buf, BUF_LEN, 
       		                  &keysym, &status);
       else 
+#endif
 #endif
         count = XmbLookupString(windev->ic, event, buf, BUF_LEN, 
 			        &keysym, &status);
