@@ -125,6 +125,17 @@ static	Region	emptyRegion;
     XFreeGC(XDPY, agcntxt);
   if (clipregion)
     XDestroyRegion(clipregion);
+
+#ifdef HAVE_XFT
+  if (xft_draw != NULL)
+    {
+      XftDrawDestroy(xft_draw);
+    }
+  if (xft_alpha_draw != NULL)
+    {
+      XftDrawDestroy(xft_alpha_draw);
+    }
+#endif
   [super dealloc];
 }
 
@@ -148,6 +159,10 @@ static	Region	emptyRegion;
       self->clipregion = region;
     }
 
+#ifdef HAVE_XFT
+  xft_draw = NULL;
+  xft_alpha_draw = NULL;
+#endif
   return self;
 }
 
@@ -717,6 +732,8 @@ static	Region	emptyRegion;
       do_copy = NO;
       comp_gcv.function = GXcopy;
       break;
+    default:
+      comp_gcv.function = GXcopy;
     }
 
   if (comp_gcv.function != GXcopy)
@@ -957,7 +974,11 @@ static	Region	emptyRegion;
       int    x[count], w[count], y0, y1;
       int    yh = y * 2 + 1;   // shift y of horizontal line
       XPoint lastP, p1;
-      
+
+      // To keep compiler happy
+      lastP.x = 0;
+      lastP.y = 0;
+
       /* intersect horizontal line with path */
       for (i = 0, cnt = 0; i < count - 1; i++)
 	{
@@ -1065,6 +1086,12 @@ static	Region	emptyRegion;
       BOOL doit;
       BOOL complex = NO;
       
+      // To keep compiler happy
+      last_p.x = 0;
+      last_p.y = 0;
+      p.x = 0;
+      p.y = 0;
+
       for (j = 0; j < count; j++) 
         {
 	  doit = NO;
@@ -1236,11 +1263,11 @@ static	Region	emptyRegion;
     [self setColor: &fillColor state: COLOR_FILL];
 
   len = strlen(s);
-  width = [(XGFontInfo *)font widthOf: s lenght: len];
+  width = [(XGFontInfo *)font widthOf: s length: len];
   xp = XGWindowPointToX(self, [path currentPoint]);
   // Hack: Only draw when alpha is not zero
   if (drawingAlpha == NO || fillColor.field[AINDEX] != 0.0)
-    [(XGFontInfo *)font draw: s lenght: len 
+    [(XGFontInfo *)font draw: s length: len 
 	       onDisplay: XDPY drawable: draw
 	       with: xgcntxt at: xp];
 
@@ -1249,7 +1276,7 @@ static	Region	emptyRegion;
       NSAssert(alpha_buffer, NSInternalInconsistencyException);
 
       [self setAlphaColor: fillColor.field[AINDEX]];
-      [(XGFontInfo *)font draw: s lenght: len 
+      [(XGFontInfo *)font draw: s length: len 
 		 onDisplay: XDPY drawable: alpha_buffer
 		 with: agcntxt at: xp];
     }
@@ -1283,11 +1310,11 @@ static	Region	emptyRegion;
   if ((cstate & COLOR_FILL) == 0)
     [self setColor: &fillColor state: COLOR_FILL];
 
-  width = [(XGFontInfo *)font widthOfGlyphs: glyphs lenght: length];
+  width = [(XGFontInfo *)font widthOfGlyphs: glyphs length: length];
   xp = XGWindowPointToX(self, [path currentPoint]);
   // Hack: Only draw when alpha is not zero
   if (drawingAlpha == NO || fillColor.field[AINDEX] != 0.0)
-    [(XGFontInfo *)font drawGlyphs: glyphs lenght: length
+    [(XGFontInfo *)font drawGlyphs: glyphs length: length
 	       onDisplay: XDPY drawable: draw
 	       with: xgcntxt at: xp];
 
@@ -1296,7 +1323,7 @@ static	Region	emptyRegion;
       NSAssert(alpha_buffer, NSInternalInconsistencyException);
 
       [self setAlphaColor: fillColor.field[AINDEX]];
-      [(XGFontInfo *)font drawGlyphs: glyphs lenght: length
+      [(XGFontInfo *)font drawGlyphs: glyphs length: length
 		 onDisplay: XDPY drawable: alpha_buffer
 		 with: agcntxt at: xp];
     }
