@@ -220,7 +220,7 @@ NSMutableDictionary	*pasteboards = nil;
 {
   if (verbose)
     {
-      NSLog(@"get data for %x\n", (unsigned)self);
+      NSLog(@"get data for %p\n", self);
     }
   return data;
 }
@@ -269,12 +269,12 @@ NSMutableDictionary	*pasteboards = nil;
 {
   if (verbose)
     {
-      NSLog(@"set data for %x\n", (unsigned)self);
+      NSLog(@"set data for %p\n", self);
     }
   ASSIGN(data, d);
 }
 
-- (id) type
+- (NSString*) type
 {
   return type;
 }
@@ -367,7 +367,9 @@ NSMutableDictionary	*pasteboards = nil;
   return e;
 }
 
-- (void) addTypes: newTypes owner: newOwner pasteboard: pb
+- (void) addTypes: (NSArray*)newTypes 
+	    owner: (id)newOwner 
+       pasteboard: (id)pb
 {
   int	i;
   BOOL	wants = NO;
@@ -575,7 +577,7 @@ NSMutableDictionary	*pasteboards = nil;
 
 - (int) addTypes: (NSArray*)types
 	   owner: (id)owner
-      pasteboard: (id)pboard
+      pasteboard: (NSPasteboard*)pboard
 	oldCount: (int)count;
 - (NSString*) availableTypeFromArray: (NSArray*)types
 			 changeCount: (int*)count;
@@ -586,7 +588,7 @@ NSMutableDictionary	*pasteboards = nil;
 	  mustBeCurrent: (BOOL)flag;
 - (int) declareTypes: (NSArray*)types
 	       owner: (id)owner
-	  pasteboard: (id)pboard;
+	  pasteboard: (NSPasteboard*)pboard;
 - (PasteboardEntry*) entryByCount: (int)count;
 - (NSString*) name;
 - (void) releaseGlobally;
@@ -1174,6 +1176,9 @@ init(int argc, char** argv, char **env)
 
   for (count = 0; count < NSIG; count++)
     {
+#ifdef	SIGPROF
+      if (count == SIGPROF) continue;
+#endif
       signal((int)count, ihandler);
     }
 #ifdef SIGPIPE
