@@ -18,7 +18,7 @@
    You should have received a copy of the GNU General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 
@@ -1168,7 +1168,7 @@ pasteboardTypeForMimeType(Display *xDisplay, NSZone *zone, Atom *typelist)
   Atom *type = typelist;
   NSMutableArray *newTypes = [[NSMutableArray allocWithZone: zone] init];
 
-  while(*type != None)
+  while (*type != None)
     {
       char *s = XGetAtomName(xDisplay, *type);
       
